==> magearmor-0.1.tar.gz: magearmor-0.1/README.md <==
# 🛡️ MageArmor

MageArmor é uma biblioteca simples, direta e eficiente desenvolvida para proteger sistemas de IA contra ataques de prompt injection. Com funções otimizadas, nossa biblioteca ajuda a analisar prompts e reforçar a segurança, tornando suas aplicações mais resistentes a injeções de comandos indesejados.

## 🌟 Características
- **Segurança Avançada**: Protege contra ataques de prompt injection em ambientes de IA.
- **Multiplataforma**: Disponível em Python e JavaScript, integrando-se facilmente aos seus projetos.
- **Fácil Integração**: Apenas uma função para aplicar diretamente na sua variável de prompt.

## 🚀 Começando

Em Python:

```python
# Exemplo de como importar a MageArmor em Python
from mageArmor import guardCast
```

Em JavaScript:

```javascript
// Exemplo de como importar a MageArmor em JavaScript
import { guardCast } from 'mageArmor';
```

> 💡 **Nota**: Certifique-se de que o ambiente está configurado corretamente para suportar Python ou JavaScript, dependendo do projeto.

### 📖 [Documentação Completa](#)
Encontre todas as funcionalidades, detalhes de instalação e mais exemplos de uso na nossa [Documentação](#). Explore nossos guias para começar com facilidade e proteger suas aplicações.

## 📬 Contato

Redes sociais:
- [@hollowv4x](https://twitter.com/hollowv4x)
- [@naomaisalive](https://twitter.com/naomaisalive)

Para questões, colaborações ou suporte, entre em contato pelo email:
- Gmail: contato.gsr13@gmail.com
- Outlook: contato.rodrigocorreiaba753@outlook.com.br


**Proteja suas IAs e fortaleça a segurança do seu sistema com o MageArmor!** 🔒

==> magearmor-0.2.tar.gz: magearmor-0.2/README.md <==
# 🛡️ MageArmor

MageArmor é uma biblioteca simples, direta e eficiente desenvolvida para proteger sistemas de IA contra ataques de prompt injection. Com funções otimizadas, nossa biblioteca ajuda a analisar prompts e reforçar a segurança, tornando suas aplicações mais resistentes a injeções de comandos indesejados.

## 🌟 Características
- **Segurança Avançada**: Protege contra ataques de prompt injection em ambientes de IA.
- **Multiplataforma**: Disponível em Python e JavaScript, integrando-se facilmente aos seus projetos.
- **Fácil Integração**: Apenas uma função para aplicar diretamente na sua variável de prompt.

## 🚀 Começando

Em Python:

```python
# Exemplo de como importar a MageArmor em Python
from mageArmor import guardCast
```

Em JavaScript:

```javascript
// Exemplo de como importar a MageArmor em JavaScript
import { guardCast } from 'mageArmor';
```

> 💡 **Nota**: Certifique-se de que o ambiente está configurado corretamente para suportar Python ou JavaScript, dependendo do projeto.

### 📖 [Documentação Completa](#)
Encontre todas as funcionalidades, detalhes de instalação e mais exemplos de uso na nossa [Documentação](https://magearmor.gitbook.io/documentacao-magearmor). Explore nossos guias para começar com facilidade e proteger suas aplicações.

## 📬 Contato

Redes sociais:
- [@hollowv4x](https://twitter.com/hollowv4x)
- [@naomaisalive](https://twitter.com/naomaisalive)

Para questões, colaborações ou suporte, entre em contato pelo email:
- Gmail: contato.gsr13@gmail.com
- Outlook: contato.rodrigocorreiaba753@outlook.com.br


**Proteja suas IAs e fortaleça a segurança do seu sistema com o MageArmor!** 🔒
